import { 
  select,
  csv,
  scaleLinear,
  scaleBand,
  max,
  axisLeft,
  axisBottom
} from 'd3';

import { calculateFrequency } from './calculateFrequency';

const svg = select('svg');
svg.style('background-color', '#fdbe85');

const width  = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const xValue = d => d.frequency;
  const yValue = d => d.note;
  const margin = {top: 20, right: 60, bottom: 30, left: 100 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);
  
  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.2);
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  g.append('g').call(axisLeft(yScale));
  g.append('g').call(axisBottom(xScale))
    .attr('transform', `translate(0, ${innerHeight})`);
     
  g.selectAll('rect').data(data)
    .enter().append('rect')
      .attr('y', d => yScale(yValue(d)))
      .attr('width', d => xScale(xValue(d)))
      .attr('height', yScale.bandwidth())
  
};

csv('https://vizhub.com/rubens2005/datasets/poor-little-fool_track-12.csv').then(data => {
  data.forEach(d => {
    d.start = +d.start;
    d.end = +d.end;
    d.duration = +d.duration;
  });
  const freq = calculateFrequency(data);
  render(freq);
});